#!/bin/bash
#
#  3 - Configure default network parameters
#

date=`date +"%d/%m/%Y %H:%M"`
echo -en "\n\n****************************************************\n"
echo "[$date] Configurant paràmetres de xarxa per defecte i deshabilitant el NetworkManager"
echo "****************************************************"

#
# Get selected network device
#
if [ -e /etc/Linkat/data/net_device ]; then
	DEV=`cat /etc/Linkat/data/net_device`
else
	echo -en "Error:: No s'ha definit el dispositiu de xarxa." 
	exit 1
fi

#
# Backup stuff
#
if [ -e /etc/sysconfig/network/config ]; then
	res=$(mv /etc/sysconfig/network/config /etc/sysconfig/network/config.orig 2>&1)
	if [ ! $? -eq 0 ];then
		echo -en "Error:: No s'ha pogut fer una còpia de seguretat de /etc/sysconfig/network/config; $res"
	fi
else
	echo -en "Error:: No existeix un fitxer de configuració global de la xarxa!\n"
fi

if [ -e /etc/sysconfig/network/ifcfg-$DEV ]; then
	res=$(mv /etc/sysconfig/network/ifcfg-$DEV /etc/Linkat/backup/ifcfg-$DEV.orig 2>&1)
	if [ ! $? -eq 0 ];then
		echo -en "Error:: No s'ha pogut fer una còpia de seguretat de /etc/sysconfig/network/ifcfg-$DEV; $res"
	else
		if [ -e /etc/sysconfig/network/routes ]; then
			res=$(mv /etc/sysconfig/network/routes /etc/Linkat/backup/routes.orig 2>&1)
			if [ ! $? -eq 0 ];then
				echo -en "Error:: No s'han pogut fer una còpia de seguretat de /etc/sysconfig/network/routes; $res"
			fi
		fi
	fi
else
	echo -en "Error:: No existeix un fitxer de configuració d'$DEV! Intentant configurar la xarxa igualment...\n"
fi

if [ -e /etc/resolv.conf ]; then
	res=$(mv /etc/resolv.conf /etc/resolv.conf.orig 2>&1)
	if [ ! $? -eq 0 ];then
		echo -en "Error:: No s'ha pogut fer una còpia de seguretat de /etc/resolv.conf; $res"
	fi
fi

res=$(cp /etc/Linkat/data/config.network.Linkat /etc/sysconfig/network/config 2>&1)
if [ ! $? -eq 0 ];then
	echo -en "Error:: No s'ha pogut modificar la configuració de xarxa; $res"
else
	res=$(chmod 644 /etc/sysconfig/network/config && chown root:root /etc/sysconfig/network/config 2>&1)
	if [ ! $? -eq 0 ];then
		echo -en "Error:: No s'han pogut canviar els permisos de /etc/sysconfig/network/config; $res"
	fi
fi      

res=$(cp /etc/Linkat/data/ifcfg-$DEV.Linkat /etc/sysconfig/network/ifcfg-$DEV 2>&1)
if [ ! $? -eq 0 ];then
	echo -en "Error:: No s'ha pogut modificar la configuració de xarxa; $res"
else
	echo -en "Success: Canviat el fitxer ifcfg-$DEV\n"
	res=$(chmod 644 /etc/sysconfig/network/ifcfg-$DEV && chown root:root /etc/sysconfig/network/ifcfg-$DEV 2>&1)
	if [ ! $? -eq 0 ];then
		echo -en "Error:: No s'han pogut canviar els permisos de /etc/sysconfig/network/ifcfg-$DEV; $res"
	fi
fi      

res=$(cp /etc/Linkat/data/routes.Linkat /etc/sysconfig/network/routes 2>&1)
if [ ! $? -eq 0 ];then
	echo -en "Error:: No s'ha pogut afegir la ruta per defecte; $res"
else
	res=$(chmod 644 /etc/sysconfig/network/routes && chown root:root /etc/sysconfig/network/routes 2>&1)
	if [ ! $? -eq 0 ];then
		echo -en "Error:: No s'han pogut canviar els permisos de /etc/sysconfig/network/routes; $res"
	fi
fi

echo -en "Canviant el domini per defecte\n" 
cat /etc/Linkat/data/resolv.conf.Linkat | sed s/__DOMINI__/$DOMINI/g > /etc/resolv.conf
if [ ! $? -eq 0 ];then
	echo -en "Error:: Hi ha hagut un error al aplicar la configuració predeterminada del DNS; $res\n"
else
	echo -en "Success:: S'ha canviat correctament el fitxer resolv.conf\n"
fi

res=$(/etc/init.d/./network restart 2>&1)
if [ ! $? -eq 0 ];then
	echo -en "Error:: No s'ha pogut reiniciar la xarxa; $res"
else
	echo -en "Xarxa configurada i reiniciada\n"
fi

#
# Check that the network has been properly set up
#
ip=$(/sbin/ifconfig | grep "inet addr" | grep -v "127.0.0.1"| awk '{print $2}' | cut -d ":" -f 2 | head -1)
if [ ! $? -eq 0 ];then
	echo -en "Error:: No s'ha pogut llegir l'adreça de la màquina"
	exit 1
else
	export IP1=$(echo $ip | cut -d "." -f 1 2>&1)
	export IP2=$(echo $ip | cut -d "." -f 2 2>&1)
	export IP3=$(echo $ip | cut -d "." -f 3 2>&1)
	export IP4=$(echo $ip | cut -d "." -f 4 2>&1)
fi

