#!/bin/bash
#
# Zenity GUI to setup network parameters giving default values.
#
# Author: Jordi "Txor" Casas Ríos <jordi.casas@opentrends.net>
#

# Functions
check_ip()
{
	echo "$1" | grep -E '^(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9])\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9]|0)\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9]|0)\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[0-9])$' > /dev/null 2>&1
	return $?
}

# Ask user which network interface is preferred
LIST_DEV=`ip link sh | grep ^[0-9] | grep -v " lo" | cut -d":" -f 2 | tr -d " "`
DEV=""

while [ "$DEV" == "" ];
do
        DEV=$(echo $LIST_DEV | zenity --list \
         --title "Seleccioneu el dispositiu de xarxa" \
         --text "Seleccioneu el dispositiu de xarxa on oferim serveis." \
         --column "Dispositiu"  $LIST_DEV )
done


# Variables
ZENITY=$(which zenity)
IFCFG_FILE=/etc/Linkat/data/ifcfg-$DEV.Linkat
ROUTES_FILE=/etc/Linkat/data/routes.Linkat
RESOLV_FILE=/etc/Linkat/data/resolv.conf.Linkat
DEV_FILE=/etc/Linkat/data/net_device
IP="192.168.0.240"
NET="255.255.255.0"
GATEWAY="192.168.0.1"
DNS="213.176.161.16"

echo $DEV >$DEV_FILE

# Loop until user chooses right values for the network configuration.
FI=0
while [ $FI -eq 0 ] ; do
	FI=1
	INFO=$($ZENITY --title="Configuració IP" --width="500" --list --text="Configureu els paràmetres de xarxa:" --column="IP" --column="NETMASK" --column="GATEWAY" --column="DNS" ${IP} ${NET} ${GATEWAY} ${DNS} --editable --print-column="ALL" --separator=":")
	if [ $? -ne 0 ] ; then
		FI=0
		$ZENITY --error --text="Si us plau accepteu la configuració." --timeout=20
	else
		if [ -z $INFO ] ; then
			FI=0
			$ZENITY --error --text="Si us plau seleccioneu una linia." --timeout=20
		else
			NEW_IP=$(echo $INFO | cut -d ":" -f 1)
			check_ip $NEW_IP
			if [ $? -ne 0 ]; then
				FI=0
				$ZENITY --error --text="L'adreça IP $NEW_IP no és correcte, si us plau introduïu-la de nou." --timeout=20
			else
				NEW_NET=$(echo $INFO | cut -d ":" -f 2)
				check_ip $NEW_NET
				if [ $? -ne 0 ]; then
					FI=0
					$ZENITY --error --text="La màscara de xarxa $NEW_NET no és correcte, si us plau introduïu-la de nou." --timeout=20
					#TODO: Check if netmask is valid (if have the form 1*0* in binary notation).
				else
					NEW_GATEWAY=$(echo $INFO | cut -d ":" -f 3)
					check_ip $NEW_GATEWAY
					if [ $? -ne 0 ]; then
						FI=0
						$ZENITY --error --text="La porta d'enllaç $NEW_GATEWAY no és correcte, si us plau introduïu-la de nou." --timeout=20
					else
						NEW_DNS=$(echo $INFO | cut -d ":" -f 4)
						check_ip $NEW_DNS
						if [ $? -ne 0 ]; then
							FI=0
							$ZENITY --error --text="El servidor DNS $NEW_DNS no és correcte, si us plau introduïu-lo de nou." --timeout=20
						fi
					fi
				fi
			fi
		fi
	fi
done

# Write ifcfg-eth configuration
cat <<EOF > /etc/Linkat/data/ifcfg-$DEV.Linkat
BOOTPROTO='static'
IPADDR='$NEW_IP'
NETMASK='$NEW_NET'
MTU=''
NETWORK=''
STARTMODE='auto'
USERCONTROL='no'
EOF

# Write routes configuration
cat <<EOF > /etc/Linkat/data/routes.Linkat
default $NEW_GATEWAY - -
EOF

# Write resolv.conf configuration
cat <<EOF > /etc/Linkat/data/resolv.conf.Linkat
search __DOMINI__
nameserver 127.0.0.1
nameserver $NEW_DNS
EOF

